@@ -31,6 +31,8 @@ module Stomp
         end
         #
         return nil if line.nil?
+        #An extra \n at the beginning of the frame, possibly not caught by is_ready?
+        line = '' if line == "\n"
         # p [ "wiredatain_01", line ]
         line = _normalize_line_end(line) if @protocol >= Stomp::SPL_12
         # If the reading hangs for more than X seconds, abort the parsing process.
@@ -171,7 +173,7 @@ module Stomp
           end
         end
         _wire_write(used_socket,"")
-        used_socket.write body
+        used_socket.write body unless body == ''
         used_socket.write "\0"
         used_socket.flush if autoflush
 
@@ -209,7 +211,7 @@ module Stomp
     def open_ssl_socket()
       require 'openssl' unless defined?(OpenSSL)
       begin # Any raised SSL exceptions
-        ctx = OpenSSL::SSL::SSLContext.new
+        ctx = @sslctx_newparm ? OpenSSL::SSL::SSLContext.new(@sslctx_newparm) : OpenSSL::SSL::SSLContext.new
         ctx.verify_mode = OpenSSL::SSL::VERIFY_NONE # Assume for now
         #
         # Note: if a client uses :ssl => true this would result in the gem using
@@ -275,6 +277,13 @@ module Stomp
               ctx.ciphers = Stomp::DEFAULT_CIPHERS # Just use Stomp defaults
             end
           end
+
+          # Set SSLContext Options if user asks for it in Stomp::SSLParams
+          # and SSL supports it.
+          if @ssl.ssl_ctxopts && ctx.respond_to?(:options=)
+	          ctx.options = @ssl.ssl_ctxopts
+          end
+
         end
 
         #
@@ -306,6 +315,10 @@ module Stomp
         lp = log_params.clone
         lp[:ssl_exception] = ex
         slog(:on_ssl_connectfail, lp)
+        if ssl
+          # shut down the TCP socket - we just failed to do the SSL handshake in time
+          ssl.close
+        end
         #
         raise # Reraise
       end
